@@ -1,7 +1,7 @@
 int.multi <- function(f, nodes, ...) {
-    vapply(X         = mapply(FUN      = stats::integrate,
-                              lower    = utils::head(nodes, -1L),
-                              upper    = utils::tail(nodes, -1L),
+    vapply(X         = mapply(FUN      = integrate,
+                              lower    = head(nodes, -1L),
+                              upper    = tail(nodes, -1L),
                               MoreArgs = list(f = match.fun(f), ...),
                               SIMPLIFY = FALSE),
            FUN       = `[[`,
